@@ -38,7 +38,7 @@ class BaseScanner(object):
 
     def trigger_deleted(self, filepath):
         """Triggers deleted event if the flie doesn't exist."""
-        if not os.path.exist(filepath):
+        if not os.path.exists(filepath):
             self._trigger('deleted', filepath)
 
     def trigger_init(self):
@@ -108,7 +108,7 @@ class BaseScanner(object):
         The filepath can be assumed to be a file (not a directory).
         """
         if self._validator is not None:
-            return self._validator(filepath, self.path)
+            return self._validator(filepath)
         if filepath.endswith('.py') and not os.path.basename(filepath).startswith('.'):
             return True
         return False
